#!/bin/sh
echo 'name: simple-sendfile
version: 0.2.4
id: simple-sendfile-0.2.4-d0d1ad7b5347c5b5c77b73be8597470a

license: BSD3
copyright:
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
stability:
homepage:
package-url:
synopsis: Cross platform library for the sendfile system call
description: Cross platform library for the sendfile system call.
             This library tries to call minimum system calls which
             are the bottleneck of web servers.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
pkgpath: devel/hs-simple-sendfile
exposed: True
exposed-modules: Network.Sendfile
hidden-modules: Network.Sendfile.Fallback Network.Sendfile.Types
trusted: False
import-dirs: /usr/local/lib/ghc/simple-sendfile-0.2.4
library-dirs: /usr/local/lib/ghc/simple-sendfile-0.2.4
hs-libraries: HSsimple-sendfile-0.2.4
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
         conduit-0.4.2-e8d5c4153d76f3672eace08aa0cd55be
         network-2.3.1.0-e56ec3d5abd17b7b386690bf49d424ab
         transformers-0.3.0.0-2889ebed7e61112cda7ded5e4c153bcf
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-simple-sendfile-0.2.4/html/simple-sendfile.haddock
haddock-html: /usr/local/share/doc/hs-simple-sendfile-0.2.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
